logging

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 30, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Setup

func Setup() (*slog.Logger, func() error, error)

Setup creates a JSON logger that writes to ~/.milo/debug.log. It returns the logger, a cleanup function to close the log file, and any error. The log file is truncated on each session so it reflects only the current run.

Types

This section is empty.

Jump to